ExRatatui.Widgets.Clear (ExRatatui v0.7.1)

Copy Markdown View Source

A widget that resets all cells in its area to empty (space) characters.

Useful for rendering overlays on top of existing content — render a Clear over the area first, then render the overlay widget on top.

Examples

iex> %ExRatatui.Widgets.Clear{}
%ExRatatui.Widgets.Clear{}

Summary

Types

t()

@type t() :: %ExRatatui.Widgets.Clear{}